Build the full-width title band of a poster
Usage
poster_title(
title,
subtitle = NULL,
authors = NULL,
affiliations = NULL,
funding = NULL,
logo = NULL,
theme = poster_theme(),
width = NULL
)Arguments
- title
Main title string.
- subtitle
Optional subtitle string.
Optional author list string (e.g.
"*A. One, B. Two").- affiliations
Optional affiliations string.
- funding
Optional acknowledgement/funding string, drawn smaller.
- logo
Optional path to a logo image, placed at the right edge.
- theme
A
poster_theme()object.- width
Wrap width for all text rows, as a grid::unit or millimetres. Typically the poster width minus outer margins.
NULLdisables wrapping (not recommended for long titles).
Examples
g <- poster_title("A Title", authors = "*A. Author", theme = poster_theme())